==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS"," ");
define("_NOCOMMENTS"," ");

define("_UCOMMENT","");
define("_REVIEWS","");
define("_SEARCHUSERS","    ");
define("_SEARCHSECTIONS","   ");
define("_SEARCHREVIEWS","  ");
define("_SEARCHIN","  :");
define("_ARTICLES","");
define("_ALLAUTHORS"," ");
define("_ALL","");
define("_WEEK","");
define("_WEEKS","");
define("_MONTH","");
define("_MONTHS","");
define("_SEARCHON"," :");
define("_SSTORIES","");
define("_SSECTIONS","");
define("_SUSERS","");
define("_NOMATCHES","     ");
define("_PREVMATCHES","");
define("_NEXTMATCHES","");
define("_INSECTION","  ");
define("_NONAME","  ");
define("_SCOMMENTS","");
define("_SEARCHRESULTS"," ");
define("_CONTRIBUTEDBY","");
define("_UCOMMENTS","");
define("_MATCHTITLE"," ");
define("_MATCHTEXT","  ");
define("_MATCHBOTH","    ");
define("_SREPLY","³");
define("_SREPLIES","³");
define("_ATTACHART","  ");
define("_PAGES","");
define("_REVIEWSCORE","  ");
define("_PAGE","");



?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS"," ");
define("_NOCOMMENTS"," ");

define("_UCOMMENT","");
define("_REVIEWS","");
define("_SEARCHUSERS","    ");
define("_SEARCHSECTIONS","   ");
define("_SEARCHREVIEWS","  ");
define("_SEARCHIN","  :");
define("_ARTICLES","");
define("_ALLAUTHORS"," ");
define("_ALL","");
define("_WEEK","");
define("_WEEKS","");
define("_MONTH","");
define("_MONTHS","");
define("_SEARCHON"," :");
define("_SSTORIES","");
define("_SSECTIONS","");
define("_SUSERS","");
define("_NOMATCHES","     ");
define("_PREVMATCHES","");
define("_NEXTMATCHES","");
define("_INSECTION","  ");
define("_NONAME","  ");
define("_SCOMMENTS","");
define("_SEARCHRESULTS"," ");
define("_CONTRIBUTEDBY","");
define("_UCOMMENTS","");
define("_MATCHTITLE"," ");
define("_MATCHTEXT","  ");
define("_MATCHBOTH","    ");
define("_SREPLY","³");
define("_SREPLIES","³");
define("_ATTACHART","  ");
define("_PAGES","");
define("_REVIEWSCORE","  ");
define("_PAGE","");



?>
